<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 Yun-young Lee
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: db.pgsql.php,v 1.35 2004/04/10 16:05:00 lseeker Exp $
 */

function &quote_string(&$str)
{
    return get_magic_quotes_gpc() ? $str : addslashes($str);
}

// {{{ DBConnection Pooling
function &DBConnectionPool($connect = TRUE)
{
    static $dbconn;
    static $called = FALSE;

    if (!$connect) {
        if ($called) {
            $called = FALSE;
            pg_close($dbconn);
        }
        return NULL;
    }

    if (!$called) {
        $conninfo =& $GLOBALS['_DBConnectionInfo'];

        $connstr = '';
        $host = trim($conninfo[2]);
        if (!empty($host)) $connstr .= "host='{$host}' ";
        $pass = trim($conninfo[4]);
        if (!empty($pass)) $connstr .= "password='{$pass}' ";

        $connstr .= 'user=\'' . trim($conninfo[3]) . '\' ';
        $connstr .= 'dbname=\'' . trim($conninfo[5]) . '\'';

        $dbconn = pg_connect($connstr);

        if ($dbconn === FALSE) trigger_error('DB Connect Error', E_USER_ERROR);

        $called = TRUE;
    }

    return $dbconn;
}

function DBConnectionFinish()
{
    DBConnectionPool(FALSE);
}
// }}}

// {{{ Spiral-3 new DBResult class
class DBResult
{
    var $result;
    var $row_nums;
    var $row_now = 0;

    function DBResult(&$res)
    {
        $this->result =& $res;
        $this->row_nums = pg_num_rows($res);
    }

    function _DBResult()
    {
        pg_free_result($this->result);
    }

    function goNext()
    {
        return ++$this->row_now < $this->row_nums ? TRUE : FALSE;
    }

    function &numRows() {
        return $this->row_nums;
    }

    function &getValue($name) {
        return pg_fetch_result($this->result, $this->row_now, $name);
    }
}
// }}}

// {{{ Spiral-3 new DBConnection class
class DBConnection {
    var $conn;

    function DBConnection()
    {
        $this->conn =& DBConnectionPool();
    }

    function &query($command)
    {
        $result = pg_query($this->conn, $command);
        if ($result === FALSE) trigger_error('Query Error: ' . pg_last_error($this->conn), E_USER_ERROR);

        $retval = new DBResult($result);
        return $retval->numRows() ? $retval : NULL;
    }

    function exec($command, $trigger = TRUE)
    {
        $result = pg_query($this->conn, $command);

        if ($result === FALSE) {
            if ($trigger) trigger_error('Query Error: ' . pg_last_error($this->conn), E_USER_ERROR);
            return FALSE;
        }
        return TRUE;
    }

    function begin($dummy = NULL)
    {
        pg_query($this->conn, 'BEGIN');
    }

    function commit($dummy = NULL)
    {
        pg_query($this->conn, 'COMMIT');
    }

    function &getArticleCount()
    {
        return pg_fetch_result(pg_query($this->conn, 'SELECT last_value FROM hboard_db_article_idx_seq WHERE is_called=TRUE'), 0, 0);
    }

    function &getLastArticleNum()
    {
        return pg_fetch_result(pg_query($this->conn, 'SELECT currval(\'hboard_db_article_idx_seq\')'), 0, 0);
    }

    function &getVersion()
    {
        return pg_fetch_result(pg_query($this->conn, 'SELECT version()'), 0, 0);
    }
}
// }}}

?>
