<?php
/* vim600: et ts=4 sts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 Yun-young Lee
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: db.sqlite.php,v 1.7 2004/04/10 16:30:47 lseeker Exp $
 */

function &quote_string(&$str)
{
    return sqlite_escape_string(get_magic_quotes_gpc() ? stripslashes($str) : $str);
}

// {{{ DBConnection Pooling
function &DBConnectionPool($connect = TRUE)
{
    static $dbconn;
    static $called = FALSE;

    if (!$connect) {
        if ($called) {
            $called = FALSE;
            sqlite_close($dbconn);
        }
        return NULL;
    }

    if (!$called) {
        $conninfo =& $GLOBALS['_DBConnectionInfo'];

        $dbconn = sqlite_open('db/' . trim($conninfo[5]) . '.db');

        if ($dbconn === FALSE) trigger_error('DB Connect Error', E_USER_ERROR);

        $called = TRUE;
    }

    return $dbconn;
}

function DBConnectionFinish()
{
    DBConnectionPool(FALSE);
}
// }}}

// {{{ Spiral-3 new DBResult class
class DBResult
{
    var $result;
    var $row_nums;
    var $row_now = 0;

    function DBResult(&$res)
    {
        $this->result =& $res;
        $this->row_nums = sqlite_num_rows($res);
    }

    function goNext()
    {
        sqlite_next($this->result);
        return ++$this->row_now < $this->row_nums ? TRUE : FALSE;
    }

    function &numRows() {
        return $this->row_nums;
    }

    function &getValue($name) {
        return sqlite_column($this->result, $name);
    }
}
// }}}

// {{{ Spiral-3 new DBConnection class
class DBConnection {
    var $conn;

    function DBConnection()
    {
        $this->conn =& DBConnectionPool();
    }

    function &query($command)
    {
        $result = sqlite_query($this->conn, $command);
        if ($result === FALSE) trigger_error('Query Error: ' . sqlite_error_string(sqlite_last_error($this->conn)), E_USER_ERROR);

        $retval = new DBResult($result);
        return $retval->numRows() ? $retval : NULL;
    }

    function exec($command, $trigger = TRUE)
    {
        $result = sqlite_query($this->conn, $command);

        if ($result === FALSE) {
            if ($trigger) trigger_error('Query Error: ' . sqlite_error_string(sqlite_last_error($this->conn)), E_USER_ERROR);
            return FALSE;
        }
        return TRUE;
    }

    function begin($dummy = NULL)
    {
        sqlite_query($this->conn, 'BEGIN');
    }

    function commit($dummy = NULL)
    {
        sqlite_query($this->conn, 'COMMIT');
    }

    function &getArticleCount()
    {
        return sqlite_column(sqlite_query($this->conn, 'SELECT count(*) FROM hboard_db_article'), 0);
    }

    function &getLastArticleNum()
    {
        return sqlite_last_insert_rowid($this->conn);
    }

    function &getVersion()
    {
        return 'SQLite ' . sqlite_libversion();
    }
}
// }}}

?>
