<?php
/* vim600: noet ts=4 sw=4 fdm=marker
 *
 * EtchiBBS UTF-8 - Gallery Web Board
 * Copyright (C) 2004 Yun-young Lee
 * 
 * See LICENSE for license condition.
 *
 * http://etchibbs.kldp.net
 * $Id: form.php,v 1.4 2004/05/12 06:56:59 lseeker Exp $
 */

// {{{ class Form
class Form extends Container // implements show
{
    var $action;
    var $method;
    var $upload;
	var $onsubmit_func = NULL;

    function Form($action, $method = 'get', $upload = FALSE)
    {
        $this->Container(); // parent::__construct();

        $this->action = $action;
        $this->method = $method;
        $this->upload = $upload;
    }

	function onSubmit($func)
	{
		$this->onsubmit_func = $func;
	}

    function show()
    {
        echo "<form action=\"{$this->action}\" method=\"{$this->method}\"";
        if ($this->upload) echo ' enctype="multipart/form-data"';
		if ($this->onsubmit_func) echo " onsubmit=\"return {$this->onsubmit_func};\"";
        echo '>';
        parent::show();
        echo '</form>';
    }
}
// }}}

class FormEntry
{
	var $name;
	var $value;

	function FormEntry($name, $value = NULL)
	{
		$this->name  = htmlspecialchars($name);
		$this->value = htmlspecialchars($value);
	}

	function &getLabel(&$entry)
	{
		$Label = new Container;
		$Label->addEntry(new Text("<label for=\"{$this->name}\">"));
		$Label->addEntry($entry);
		$Label->addEntry(new Text('</label>'));

		return $Label;
	}
}

// {{{ text(name, value, size, maxlength = 0)
class FormEntryText extends FormEntry
{
	var $size;
	var $maxlength;

	function FormEntryText($name, $value, $size, $maxlength = 0)
	{
		$this->FormEntry($name, $value);

		$this->size = $size;
		$this->maxlength = $maxlength;
	}

	function show()
	{
		echo "<input type=\"text\" id=\"{$this->name}\" name=\"{$this->name}\" value=\"{$this->value}\" size=\"{$this->size}\" ";
		if ($this->maxlength) echo "maxlength=\"{$this->maxlength}\" ";
		echo '/> ';
	}
}
// }}}

// {{{ file(name, size)
class FormEntryFile extends FormEntry // implements show
{
	var $size;

	function FormEntryFile($name, $size)
	{
		$this->FormEntry($name);
		$this->size = $size;
	}

	function show()
	{
		echo "<input type=\"file\" id=\"{$this->name}\" name=\"{$this->name}\" size=\"{$this->size}\" /> ";
	}
}
// }}}

// {{{ select(name, value, list)
class FormEntrySelect extends FormEntry
{
	var $list;

	function FormEntrySelect($name, $value, $list)
	{
		$this->FormEntry($name, $value);
		$this->list =& $list;
	}

	function show()
	{
		echo "<select name=\"{$this->name}\" id=\"{$this->name}\">";
		foreach ($this->list as $value => $name) {
			echo '<option value="', htmlspecialchars($value), '"';
			if ($value == $this->value) echo ' selected="selected"';
			echo '>', htmlspecialchars($name), '</option>';
		}
		echo "</select> ";
	}
}
// }}}

// {{{ submit(name, value)
class FormEntrySubmit extends FormEntry // implements show
{
	function show()
	{
		echo '<input type="submit" ';
		if ($this->name) echo "name=\"{$this->name}\" id=\"{$this->name}\"";
		echo "value=\"{$this->value}\" /> ";

	}
}
// }}}

// {{{ hidden(name, value)
class FromEntryHidden extends FormEntry
{
	function show()
	{
		echo "<input type=\"hidden\" name=\"{$this->name}\" valye=\"{$this->value}\" />";
	}
}
// }}}

?>
